@@ -92,21 +92,17 @@ struct _SpecialOption
 const specialOptions[] =
 {
     {"close_window_key", CORE_NAME, "Window Close", true, OptionKey},
-    {"run_key", CORE_NAME, "Run Command", true, OptionKey},
-    {"main_menu_key", CORE_NAME, "Popup Launch Menu", true, OptionKey},
     {"lower_window_key", CORE_NAME, "Window Lower", true, OptionKey},
     {"toggle_window_maximized_key", CORE_NAME, "Window Maximize", true, OptionKey},
     {"minimize_window_key", CORE_NAME, "Window Minimize", true, OptionKey},
     {"toggle_window_maximized_horizontally_key", CORE_NAME, "Window Maximize Horizontal", true, OptionKey},
     {"toggle_window_maximized_vertically_key", CORE_NAME, "Window Maximize Vertical", true, OptionKey},
     {"show_desktop_key", CORE_NAME, "Toggle Showing Desktop", true, OptionKey},
-    {"run_command_screenshot_key", CORE_NAME, "Desktop Screenshot", true, OptionKey},
-    {"run_command_window_screenshot_key", CORE_NAME, "Window Screenshot", true, OptionKey},
     {"window_menu_key", CORE_NAME, "Window Operations Menu", true, OptionKey},
     {"toggle_window_shaded_key", CORE_NAME, "Window Shade", true, OptionKey},
     {"raise_window_key", CORE_NAME, "Window Raise", true, OptionKey},
     {"toggle_window_fullscreen_key", CORE_NAME, "Window Fullscreen", true, OptionKey},
-    {"run_command11_key", CORE_NAME, "Kill Window", true, OptionKey},
+    {"run_command11_key", "commands", "Kill Window", true, OptionKey},
     {"initiate_key", "move", "Window Move", true, OptionKey},
     {"initiate_key", "resize", "Window Resize", true, OptionKey},
     {"rotate_right_key", "rotate", "Switch to Next Desktop", true, OptionKey},
@@ -171,13 +167,11 @@ const specialOptions[] =
     {"autoraise_delay", CORE_NAME, "AutoRaiseInterval", false, OptionInt},
     {"flip_time", "rotate", "ElectricBorderDelay", false, OptionInt},
 
-    {"command_screenshot", CORE_NAME, NULL, true, OptionSpecial},
-    {"command_window_screenshot", CORE_NAME, NULL, true, OptionSpecial},
     {"unmaximize_window_key", CORE_NAME, NULL, true, OptionSpecial},
     {"maximize_window_key", CORE_NAME, NULL, true, OptionSpecial},
     {"maximize_window_horizontally_key", CORE_NAME, NULL, true, OptionSpecial},
     {"maximize_window_vertically_key", CORE_NAME, NULL, true, OptionSpecial},
-    {"command11", CORE_NAME, NULL, true, OptionSpecial},
+    {"command11", "commands", NULL, true, OptionSpecial},
     {"click_to_focus", CORE_NAME, NULL, false, OptionSpecial},
     {"mode", "resize", NULL, true, OptionSpecial},
     {"number_of_desktops", CORE_NAME, "Number", false, OptionSpecial},
@@ -334,15 +328,7 @@ readIntegratedOption (CCSSetting *setting)
 	break;
 
     case OptionSpecial:
-	if (specialOptions[option].settingName == "command_screenshot")
-	{
-	    ccsSetString (setting, "ksnapshot");
-	}
-	else if (specialOptions[option].settingName == "command_window_screenshot")
-	{
-	    ccsSetString (setting, "ksnapshot -c");
-	}
-	else if (specialOptions[option].settingName == "command11")
+	if (specialOptions[option].settingName == "command11")
 	{
 	    ccsSetString (setting, "xkill");
 	}
@@ -591,15 +577,7 @@ getSettingIsReadOnly (CCSSetting *setting)
     {
 
     case OptionSpecial:
-	if (specialOptions[option].settingName == "command_screenshot")
-	{
-	    return TRUE;
-	}
-	else if (specialOptions[option].settingName == "command_window_screenshot")
-	{
-	    return TRUE;
-	}
-	else if (specialOptions[option].settingName == "command11")
+	if (specialOptions[option].settingName == "command11")
 	{
 	    return TRUE;
 	}
@@ -1163,9 +1141,7 @@ writeIntegratedOption (CCSSetting *setting)
 	break;
 
     case OptionSpecial:
-	if (specialOptions[option].settingName == "command_screenshot"
-	    || specialOptions[option].settingName == "command_window_screenshot"
-	    || specialOptions[option].settingName == "command11"
+	if (specialOptions[option].settingName == "command11"
 	    || specialOptions[option].settingName == "unmaximize_window_key"
 	    || specialOptions[option].settingName == "maximize_window_key"
 	    || specialOptions[option].settingName == "maximize_window_horizontally_key"
